```{include} ../../README.md
```

```{toctree}
Home <self>
```

```{toctree}
:hidden:
:caption: User Guide
introduction
linear
ensemble
predict
imbalance
bandwidth_search
network_graph
```

```{toctree}
:hidden:
:caption: API
api
```

```{toctree}
:hidden:
:caption: For contributors
GitHub <https://github.com/uscuni/gwlearn>
```
